@@ -44,6 +44,11 @@ estimate_size_factors <- function(Y, method, verbose = FALSE){
     }
   }else if(method == "normed_sum"){
     sf <- DelayedMatrixStats::colSums2(Y)
+  }else if(method == "ratio"){
+    log_geo_means <- DelayedMatrixStats::rowMeans2(log(Y))
+    sf <- apply(Y, 2, function(cnts) {
+      exp(median((log(cnts) - log_geo_means)[is.finite(log_geo_means) & cnts > 0]))
+    })
   }else{
     stop("Unknown size factor estimation method: ", method)
   }
@@ -51,9 +56,13 @@ estimate_size_factors <- function(Y, method, verbose = FALSE){
 
 
   # stabilize size factors to have geometric mean of 1
-  all_zero_column <- is.nan(sf) | sf <= 0
+  all_zero_column <- is.na(sf) | sf <= 0
   sf[all_zero_column] <- NA
+  if(any(all_zero_column) && method == "ratio"){
+    stop("Too many zeros to calculate the size factors. Please use 'size_factors = \"normed_sum\" or 'size_factors = \"deconvolution\".")
+  }
   if(any(all_zero_column)){
+    warning(sum(all_zero_column), " columns contain too many zeros to calculate a size factor. The size factor will be fixed to 0.001")
     sf <- sf/exp(mean(log(sf), na.rm=TRUE))
     sf[all_zero_column] <- 0.001
   }else{
@@ -69,6 +78,7 @@ combine_size_factors_and_offset <- function(offset, size_factors, Y, verbose = F
   n_samples <- ncol(Y)
 
   make_offset_hdf5_mat <- is(Y, "DelayedMatrix") && is(DelayedArray::seed(Y), "HDF5ArraySeed")
+  zero_offset <- TRUE
 
   if(is.matrix(offset)){
     stopifnot(dim(offset) == c(n_genes, n_samples))
@@ -79,6 +89,7 @@ combine_size_factors_and_offset <- function(offset, size_factors, Y, verbose = F
     offset_matrix <- offset
   }else{
     stopifnot(length(offset) == 1 || length(offset) == n_samples)
+    zero_offset <- all(offset == 0)
     if(make_offset_hdf5_mat){
       offset_matrix <- DelayedArray::DelayedArray(DelayedArray::SparseArraySeed(c(n_genes, n_samples)))
       offset_matrix <- add_vector_to_each_row(offset_matrix, offset)
@@ -87,15 +98,19 @@ combine_size_factors_and_offset <- function(offset, size_factors, Y, verbose = F
     }
   }
   if(isTRUE(size_factors) || is.character(size_factors)){
+    if(! zero_offset){
+      warning("The offset is non zero, nonetheless an additional size factor is estimated. The effective 'offset' is thus 'offset + log(size_factor)'.\n",
+              "To suppress this warning either set 'size_factor = FALSE' or 'offset = 0'.")
+    }
     method <- if(isTRUE(size_factors)){
       if(requireNamespace("scran", quietly = TRUE)){
         "deconvolution"
       }else{
         "normed_sum"
       }
-    }else if(all(size_factors == c("normed_sum", "deconvolution", "poscounts"))){
+    }else if(all(size_factors == c("normed_sum", "deconvolution", "poscounts", "ratio"))){
       "normed_sum"
-    }else if(length(size_factors) == 1 && size_factors %in% c("normed_sum", "deconvolution", "poscounts")){
+    }else if(length(size_factors) == 1 && size_factors %in% c("normed_sum", "deconvolution", "poscounts", "ratio")){
       size_factors
     }else{
       stop("Cannot handle size factor ", paste0(size_factors, collapse = ", "))
