@@ -528,18 +528,38 @@ test_that("glm_gp can handle full offset matrices correctly", {
 
 
 
-test_that("glm_gp can handle gigantic counts", {
-  skip_on_os("windows", "test fails on windows")
-  # Integers with values larger than 2^31-1 = 2,147,483,647 = 2.1 * 10^9 cannot be represented by ints
-  mat <- matrix(rpois(n = 5 * 100, lambda = 3 * 10^9), nrow = 5, ncol = 100)
-  expect_true(any(mat > .Machine$integer.max))
-  rand <- rnorm(100)
-  fit <- glmGamPoi::glm_gp(mat, design = ~ rand)
-  expect_equal(exp(fit$Beta[,1]), rep(3e9, times = 5), tolerance = 0.1)
-  expect_equal(fit$Beta[,2], rep(0, times = 5), tolerance = 1e-4)
+# test_that("glm_gp can handle gigantic counts", {
+#   skip_on_os("windows", "test fails on windows")
+#   # Integers with values larger than 2^31-1 = 2,147,483,647 = 2.1 * 10^9 cannot be represented by ints
+#   mat <- matrix(rpois(n = 5 * 100, lambda = 3 * 10^9), nrow = 5, ncol = 100)
+#   expect_true(any(mat > .Machine$integer.max))
+#   rand <- rnorm(100)
+#   fit <- glmGamPoi::glm_gp(mat, design = ~ rand)
+#   expect_equal(exp(fit$Beta[,1]), rep(3e9, times = 5), tolerance = 0.1)
+#   expect_equal(fit$Beta[,2], rep(0, times = 5), tolerance = 1e-4)
+# })
+
+
+
+test_that("providing the col_data explicitly and implicitly doesn't cause issues", {
+  data <- data.frame(fav_food = sample(c("apple", "banana", "cherry"), size = 50, replace = TRUE),
+                     city = sample(c("heidelberg", "paris", "new york"), size = 50, replace = TRUE),
+                     age = rnorm(n = 50, mean = 40, sd = 15))
+  Y <- matrix(rnbinom(n = 10 * 50, mu = 3, size = 1/3.1), nrow = 10, ncol = 50)
+  rownames(Y) <- paste0("gene_", seq_len(10))
+  colnames(Y) <- paste0("person_", seq_len(50))
+
+  se <- SummarizedExperiment::SummarizedExperiment(Y, colData = data)
+
+  fit <- glm_gp(Y, design = ~ fav_food + city + age, col_data = data)
+  fit_se <- glm_gp(se, design = ~ fav_food + city + age, col_data = SummarizedExperiment::colData(se))
+  expect_equal(fit, fit_se)
+  expect_equal(colnames(SummarizedExperiment::colData(fit_se$data)), c("fav_food", "city", "age"))
+
+  cd_mod <- SummarizedExperiment::colData(se)
+  cd_mod$age[1] <- 42
+  expect_warning(
+    fit_se2 <- glm_gp(se, design = ~ fav_food + city + age, col_data = cd_mod)
+  )
 })
 
-
-
-
-
